@@ -2,18 +2,18 @@ from javaman.connexio import JManCon
 
 
 class Usuaris:
-    url_usuaris = '/usuaris'
-    url_login = '/login/usuari'
+    _url_usuaris = '/usuaris'
+    _url_login = '/login/usuari'
 
     def __init__(self, con: JManCon):
         self._con = con
 
     def list(self):
-        res = self._con.get(url=self.url_usuaris)
+        res = self._con.get(url=self._url_usuaris)
         return res.json()
 
     def get(self, usr_guid: str):
-        res = self._con.get(url=self.url_usuaris + '/' + usr_guid)
+        res = self._con.get(url=self._url_usuaris + '/' + usr_guid)
         return res.json()
 
     def delete_token(self, token: str):
