@@ -14,6 +14,7 @@ class Wms:
     _url_get_magatzem_ordre = '/magatzems_ordres/ex/{magatzem_ordre_id}'
     _url_numero_unitat_logistica = '/comptadors/numero_unitat_logistica'
     _url_troba_magatzem_ordre = '/magatzems_ordres?numero_unitat_logistica={sscc}'
+    _url_afegir_unitat_logistica_albara = '/wms/albarans/{albara_id}/expedicions'
 
     def __init__(self, con: JManCon):
         self._con = con
@@ -62,6 +63,11 @@ class Wms:
         req = self._con.post(url=self._url_post_palet, data=p_data)
         return req.json()
 
+    def afegeix_unitat_logistica_albara(self, p_albara_id: int, p_unitat_logistica: dict):
+        req = self._con.post(
+            url=self._url_afegir_unitat_logistica_albara.format(albara_id=p_albara_id), data=p_unitat_logistica)
+        return req.json()
+
     def modifica_palet(self, p_palet_id: int, p_data: dict):
         req = self._con.put(url=self._url_put_palet.format(unitat_logistica_id=p_palet_id), data=p_data)
         return req.json()
