@@ -84,5 +84,5 @@ FROM COMANDES C
 JOIN CLIENTS CL ON C.CLIENT_ID = CL.ID
 JOIN TERCERS T ON CL.TERCER_ID = T.ID
 left join SELECT_COMANDES_ESTATS_MAG(C.ID) CE ON C.ID = CE.COMANDA_ID
-where CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO IS NULL;
+where C.DATA_INICI IS NULL AND CE.MAG_PENDENT_SERVIR = 'S' AND C.DATA_ANULACIO IS NULL;
 """
